@@ -1,64 +1,39 @@
-import nonebot
 import os
 import random
 from PIL import Image, ImageDraw, ImageFont
 from pathlib import Path
 from typing import Optional
-
+from nonebot import logger
 try:
     import ujson as json
 except ModuleNotFoundError:
     import json
 
-from .data_source import FORTUNE_PATH
-
-'''
-    各主题抽签开关，仅在random抽签中生效
-    请确保不全是False
-'''
-ARKNIGHTS_FLAG = False if not nonebot.get_driver().config.arknights_flag else True
-ASOUL_FLAG = False if not nonebot.get_driver().config.asoul_flag else True
-AZURE_FLAG = False if not nonebot.get_driver().config.azure_flag else True
-GENSHIN_FLAG = False if not nonebot.get_driver().config.genshin_flag else True
-ONMYOJI_FLAG = False if not nonebot.get_driver().config.onmyoji_flag else True
-PCR_FLAG = False if not nonebot.get_driver().config.pcr_flag else True
-TOUHOU_FLAG = False if not nonebot.get_driver().config.touhou_flag else True
-TOUHOU_OLD_FLAG = False if not nonebot.get_driver().config.touhou_old_flag else True
-VTUBER_FLAG = False if not nonebot.get_driver().config.vtuber_flag else True
-GRANBLUE_FANTASY_FLAG = False if not nonebot.get_driver().config.granblue_fantasy_flag else True
-PUNISHING_FLAG = False if not nonebot.get_driver().config.punishing_flag else True
-PRETTY_DERBY_FLAG = False if not nonebot.get_driver().config.pretty_derby_flag else True
-DC4_FLAG = False if not nonebot.get_driver().config.dc4_flag else True
-EINSTEIN_FLAG = False if not nonebot.get_driver().config.einstein_flag else True
-SWEET_ILLUSION_FLAG = False if not nonebot.get_driver().config.sweet_illusion_flag else True
-LIQINGGE_FLAG = False if not nonebot.get_driver().config.liqingge_flag else True
-HOSHIZORA_FLAG = False if not nonebot.get_driver().config.Hoshizora_flag else True
-SAKURA_FLAG = False if not nonebot.get_driver().config.sakura_flag else True
+from .config import config, FORTUNE_PATH
 
 '''
     抽签主题开关，当随机抽签时判断某主题是否开启
 '''
 MainThemeEnable = {
-    "pcr":              PCR_FLAG,
-    "genshin":          GENSHIN_FLAG,
-    "vtuber":           VTUBER_FLAG,
-    "touhou":           TOUHOU_FLAG,
-    "touhou_old":       TOUHOU_OLD_FLAG,
-    "onmyoji":          ONMYOJI_FLAG,
-    "azure":            AZURE_FLAG,
-    "asoul":            ASOUL_FLAG,
-    "arknights":        ARKNIGHTS_FLAG,
-    "granblue_fantasy": GRANBLUE_FANTASY_FLAG,
-    "punishing":        PUNISHING_FLAG,
-    "pretty_derby":     PRETTY_DERBY_FLAG,
-    "dc4":              DC4_FLAG,
-    "einstein":         EINSTEIN_FLAG,
-    "sweet_illusion":   SWEET_ILLUSION_FLAG,
-    "liqingge":         LIQINGGE_FLAG,
-    "hoshizora":        HOSHIZORA_FLAG,
-    "sakura":           SAKURA_FLAG
+    "pcr":              config.pcr_flag,
+    "genshin":          config.genshin_flag,
+    "hololive":         config.hololive_flag,
+    "touhou":           config.touhou_flag,
+    "touhou_old":       config.touhou_olg_flag,
+    "onmyoji":          config.onmyoji_flag,
+    "azure":            config.azure_flag,
+    "asoul":            config.asoul_flag,
+    "arknights":        config.arknights_flag,
+    "granblue_fantasy": config.granblue_fantasy_flag,
+    "punishing":        config.punishing_flag,
+    "pretty_derby":     config.pretty_derby_flag,
+    "dc4":              config.dc4_flag,
+    "einstein":         config.einstein_flag,
+    "sweet_illusion":   config.sweet_illusion_flag,
+    "liqingge":         config.liqingge_flag,
+    "hoshizora":        config.hoshizora_flag,
+    "sakura":           config.sakura_flag
 }
-
 '''
     抽签主题对应表，第一键值为“抽签设置”或“主题列表”展示的主题名称
     Key-Value: 主题资源文件夹名-设置主题别名
@@ -66,14 +41,14 @@ MainThemeEnable = {
 MainThemeList = {
     "random":   ["随机"],
     "pcr":      ["PCR", "公主链接", "公主连接", "Pcr", "pcr"],
-    "genshin":  ["原神", "Genshin Impact", "genshin", "Genshin"],
-    "vtuber":   ["Vtuber", "VTB", "Vtb", "vtb", "管人", "holo", "猴楼"],
+    "genshin":  ["原神", "Genshin Impact", "genshin", "Genshin", "op", "原批"],
+    "hololive": ["Hololive", "hololive", "Vtb", "vtb", "管人", "holo", "猴楼"],
     "touhou":   ["东方", "touhou", "Touhou", "车万"],
     "touhou_old": 
                 ["旧东方", "旧版东方", "老东方", "老版东方", "经典东方"],
     "onmyoji":  ["阴阳师", "yys", "Yys", "痒痒鼠"],
     "azure":    ["碧蓝航线", "碧蓝", "azure", "Azure"],
-    "asoul":    ["asoul", "a手", "A手", "as", "As"],
+    "asoul":    ["Asoul", "asoul", "a手", "A手", "as", "As"],
     "arknights":["明日方舟", "方舟", "arknights", "鹰角", "Arknights", "舟游"],
     "granblue_fantasy":
                 ["碧蓝幻想", "Granblue Fantasy", "granblue fantasy", "幻想", "fantasy", "Fantasy"],
@@ -241,4 +216,4 @@ def vertical(str):
     list = []
     for s in str:
         list.append(s)
-    return "\n".join(list)
+    return "\n".join(list)
\ No newline at end of file
